/*
 * Copyright 2021 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.tomee;

import java.io.File;
import java.io.IOException;
import java.net.URL;
import java.util.HashSet;
import java.util.Set;

import org.apache.tomcat.vestige.full_installer.TomcatVestigeFullInstaller;
import org.apache.tomcat.vestige.installer.FileAdder;

/**
 * @author Gael Lalire
 */
public class TomEEWebVestigeInstaller extends TomcatVestigeFullInstaller {

    private Set<String> confExcludes = new HashSet<String>();

    public TomEEWebVestigeInstaller(final File conf) {
        super(conf);
    }

    @Override
    public void getConf(final FileAdder fileAdder) throws IOException {
        super.getConf(new FileAdder() {

            @Override
            public void addFile(final String pathFromBase, final URL url, final boolean textFile) throws IOException {
                if (!confExcludes.contains(pathFromBase)) {
                    fileAdder.addFile(pathFromBase, url, textFile);
                }
            }

            @Override
            public void addDirectory(final String pathFromBase) throws IOException {
                fileAdder.addDirectory(pathFromBase);
            }
        });
    }

}
